==> netbluemind4-4.1.62024.tar.gz: netbluemind4-4.1.62024/netbluemind/system/api/DomainTemplate.py <==
#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class DomainTemplate :
    def __init__( self):
        self.kinds = None
        pass

class __DomainTemplateSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = DomainTemplate()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.system.api.DomainTemplateKind import DomainTemplateKind
        from netbluemind.system.api.DomainTemplateKind import __DomainTemplateKindSerDer__
        kindsValue = value['kinds']
        instance.kinds = serder.ListSerDer(__DomainTemplateKindSerDer__()).parse(kindsValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.system.api.DomainTemplateKind import DomainTemplateKind
        from netbluemind.system.api.DomainTemplateKind import __DomainTemplateKindSerDer__
        kindsValue = value.kinds
        instance["kinds"] = serder.ListSerDer(__DomainTemplateKindSerDer__()).encode(kindsValue)
        return instance

==> netbluemind5-5.0.7611.tar.gz: netbluemind5-5.0.7611/netbluemind/system/api/DomainTemplate.py <==
#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class DomainTemplate:
    def __init__(self):
        self.kinds = None
        pass


class __DomainTemplateSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = DomainTemplate()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.system.api.DomainTemplateKind import DomainTemplateKind
        from netbluemind.system.api.DomainTemplateKind import __DomainTemplateKindSerDer__
        kindsValue = value['kinds']
        instance.kinds = serder.ListSerDer(
            __DomainTemplateKindSerDer__()).parse(kindsValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.system.api.DomainTemplateKind import DomainTemplateKind
        from netbluemind.system.api.DomainTemplateKind import __DomainTemplateKindSerDer__
        kindsValue = value.kinds
        instance["kinds"] = serder.ListSerDer(
            __DomainTemplateKindSerDer__()).encode(kindsValue)
        return instance
